#
# spec file for package python-ncclient
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without test
Name:           python-ncclient
Version:        0.5.3
Release:        lp152.3.4
Summary:        Python library for NETCONF clients
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://ncclient.org
Source:         https://files.pythonhosted.org/packages/source/n/ncclient/ncclient-%{version}.tar.gz
Patch0:         pr-109.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       %{python_module lxml >= 3.3.0}
Requires:       %{python_module paramiko >= 1.15.0}
Requires:       %{python_module setuptools > 0.6}
Requires:       %{python_module six}
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module lxml >= 3.3.0}
BuildRequires:  %{python_module paramiko >= 1.15.0}
BuildRequires:  %{python_module setuptools > 0.6}
BuildRequires:  %{python_module six}
%endif
%python_subpackages

%description
ncclient is a Python library that facilitates client-side scripting
and application development around the NETCONF protocol.

%package -n python-ncclient-doc
Summary:        Python NETCONF protocol library - Documentation
Group:          Documentation/HTML
BuildRequires:  %{python_module Sphinx}
Provides:       %{python_module python-ncclient-doc = %{version}}

%description -n python-ncclient-doc
This package contains documentation files for %{name}.

%prep
%setup -q -n ncclient-%{version}
%patch0 -p1

%build
%python_build
cd docs && make %{?_smp_mflags} html && rm build/html/.buildinfo

%install
%python_install
%fdupes %{buildroot}

%files %{python_files}
%doc LICENSE
%{python_sitelib}/*

%files -n python-ncclient-doc
%doc LICENSE README README.rst examples docs/build/html

%changelog
* Mon Aug  7 2017 mardnh@gmx.de
- Update to 0.5.3
  * Add notifications support
  * Add support for ecdsa keys
  * Various bug fixes
- Convert to singlespec
- Rebase patch: pr-109.patch
* Sat Sep  3 2016 mardnh@gmx.de
- update to 0.5.2:
  * Add support for Python 3
  * Improve Junos ioproc performance
  * Performance improvements
  * Updated test cases
  * Many bug and performance fixes
- fix source-url
- rebase patch: pr-109.patch
* Fri Feb  5 2016 tbechtold@suse.com
- switch to version from pypi
  This is the version used by OpenStack networking-cisco
- update to 0.4.7:
  * Add support for netconf 1.1
  * Fix multiple RPC error handling
  * Add support for cancel-commit and persist param
  * Add more examples
  * Add Huawei device support
  * Add cli command support for hpcomware v7 devices
  * Add H3C support, Support H3C CLI,Action,Get_bulk,Save,Rollback,etc.
  * Add alcatel lucent support
  * Rewrite multiple error handling
  * Add coveralls support, with shield in README.md
  * Set severity level to higher when multiple
  * Simplify logging and multi-error reporting
  * Keep stacktrace of errors
  * Check for known hosts on hostkey_verify only
  * Add check for device sending back null error_text
  * Fix RPC.raise_mode
  * Specifying hostkey_verify=False should not load_known_hosts
  * Check the correct field on rpc-error element
  * Nexus exec_command operation
  * Allow specifying multiple cmd elements in Cisco Nexus
  * Update rpc for nested rpc-errors
  * Prevent race condition in threading
  * Prevent hanging in session close
  * Support for paramiko ProxyCommand via ~/.ssh/config parsing
  * Add Juniper-specific commit operations
  * Add Huawei devices support
  * Tests/Travis support
  * ioproc transport support for Juniper devices
  * Update Cisco CSR device handler
  * Fix issue with locked method missing device handler
  * Fix for namespace definition with lxml
  * Add missing SessionError exception
  * Update docs for Nexus device handler
  * Docstring fixes
  * Typos
  * Minor bugfixes
  * Add an example for Cisco CSR1000v
- Remove nexus-support.patch . Applied upstream.
- Adjust Requires according to requirements.txt
- Split documentation into extra -doc package
- Add pr-109.patch . This lowers the lxml requirement so this
  package works with SLE12.
- Stop using openstack-suse-macros for now. This fixes the build
  for openSUSE 13.2 and SLE11SP3
* Wed Jul 29 2015 tbechtold@suse.com
- Unify spec file. Use fedora compatible files macros
* Mon Aug 26 2013 rhafer@suse.com
- added nexus-support.patch: this is required to make make ncclient
  capable of accessing cisco nexus switches (for quantum's nexus
  plugin)
* Thu Aug  8 2013 dmueller@suse.com
- (rpm-wise) downgrade to a released version 0.3.2:
  * http://ncclient.grnet.gr/0.3.2/
* Mon Jul 29 2013 speilicke@suse.com
- Require python-paramiko (for ssh transport)
- Build HTML documentation
